@@ -3,7 +3,7 @@ import logging
 from exam import before, fixture
 from mock import patch
 
-from flask import Flask, current_app
+from flask import Flask, current_app, g
 from flask.ext.login import LoginManager, AnonymousUserMixin, login_user
 
 from raven.base import Client
@@ -29,11 +29,12 @@ class User(AnonymousUserMixin):
     get_id = lambda x: 1
 
 
-def create_app(ignore_exceptions=None):
+def create_app(ignore_exceptions=None, debug=False):
     import os
 
     app = Flask(__name__)
     app.config['SECRET_KEY'] = os.urandom(40)
+    app.debug = debug
 
     if ignore_exceptions:
         app.config['RAVEN_IGNORE_EXCEPTIONS'] = ignore_exceptions
@@ -91,7 +92,7 @@ class BaseTest(TestCase):
         app = create_app(*args, **kwargs)
         raven = TempStoreClient()
         Sentry(app, client=raven)
-        return app.test_client(), raven
+        return app.test_client(), raven, app
 
 
 class FlaskTest(BaseTest):
@@ -203,41 +204,54 @@ class FlaskTest(BaseTest):
         http = event['request']
         self.assertEqual({}, http.get('data'))
 
+    def test_wrap_wsgi_status(self):
+        _, _, app_debug = self.make_client_and_raven(debug=True)
+        self.assertFalse(app_debug.extensions['sentry'].wrap_wsgi)
+
+        _, _, app_ndebug = self.make_client_and_raven(debug=False)
+        self.assertTrue(app_ndebug.extensions['sentry'].wrap_wsgi)
+
     def test_error_handler_with_ignored_exception(self):
-        client, raven = self.make_client_and_raven(ignore_exceptions=[NameError, ValueError])
+        client, raven, _ = self.make_client_and_raven(ignore_exceptions=[NameError, ValueError])
 
         response = client.get('/an-error/')
         self.assertEquals(response.status_code, 500)
         self.assertEquals(len(raven.events), 0)
 
     def test_error_handler_with_exception_not_ignored(self):
-        client, raven = self.make_client_and_raven(ignore_exceptions=[NameError, KeyError])
+        client, raven, _ = self.make_client_and_raven(ignore_exceptions=[NameError, KeyError])
 
         response = client.get('/an-error/')
         self.assertEquals(response.status_code, 500)
         self.assertEquals(len(raven.events), 1)
 
     def test_error_handler_with_empty_ignore_exceptions_list(self):
-        client, raven = self.make_client_and_raven(ignore_exceptions=[])
+        client, raven, _ = self.make_client_and_raven(ignore_exceptions=[])
 
         response = client.get('/an-error/')
         self.assertEquals(response.status_code, 500)
         self.assertEquals(len(raven.events), 1)
 
     def test_captureException_sets_last_event_id(self):
-        try:
-            raise ValueError
-        except Exception:
-            self.middleware.captureException()
-        else:
-            self.fail()
+        with self.app.test_request_context('/'):
+            try:
+                raise ValueError
+            except Exception:
+                self.middleware.captureException()
+            else:
+                self.fail()
 
-        assert self.middleware.last_event_id == self.raven.events.pop(0)['event_id']
+            event_id = self.raven.events.pop(0)['event_id']
+            assert self.middleware.last_event_id == event_id
+            assert g.sentry_event_id == event_id
 
     def test_captureMessage_sets_last_event_id(self):
-        self.middleware.captureMessage('foo')
+        with self.app.test_request_context('/'):
+            self.middleware.captureMessage('foo')
 
-        assert self.middleware.last_event_id == self.raven.events.pop(0)['event_id']
+            event_id = self.raven.events.pop(0)['event_id']
+            assert self.middleware.last_event_id == event_id
+            assert g.sentry_event_id == event_id
 
 
 class FlaskLoginTest(BaseTest):
