@@ -37,7 +37,7 @@ class LogbookHandlerTest(TestCase):
             self.assertEquals(event['logger'], __name__)
             self.assertEquals(event['level'], 'error')
             self.assertEquals(event['message'], 'This is a test error')
-            self.assertFalse('sentry.interfaces.Exception' in event)
+            self.assertFalse('exception' in event)
             self.assertTrue('sentry.interfaces.Message' in event)
             msg = event['sentry.interfaces.Message']
             self.assertEquals(msg['message'], 'This is a test error')
@@ -49,7 +49,7 @@ class LogbookHandlerTest(TestCase):
             self.assertEquals(event['logger'], __name__)
             self.assertEquals(event['level'], 'warning')
             self.assertEquals(event['message'], 'This is a test warning')
-            self.assertFalse('sentry.interfaces.Exception' in event)
+            self.assertFalse('exception' in event)
             self.assertTrue('sentry.interfaces.Message' in event)
             msg = event['sentry.interfaces.Message']
             self.assertEquals(msg['message'], 'This is a test warning')
@@ -65,7 +65,7 @@ class LogbookHandlerTest(TestCase):
             else:
                 expected = "u'http://example.com'"
             self.assertEquals(event['extra']['url'], expected)
-            self.assertFalse('sentry.interfaces.Exception' in event)
+            self.assertFalse('exception' in event)
             self.assertTrue('sentry.interfaces.Message' in event)
             msg = event['sentry.interfaces.Message']
             self.assertEquals(msg['message'], 'This is a test info with a url')
@@ -80,8 +80,8 @@ class LogbookHandlerTest(TestCase):
             event = client.events.pop(0)
 
             self.assertEquals(event['message'], 'This is a test info with an exception')
-            self.assertTrue('sentry.interfaces.Exception' in event)
-            exc = event['sentry.interfaces.Exception']
+            assert 'exception' in event
+            exc = event['exception']['values'][0]
             self.assertEquals(exc['type'], 'ValueError')
             self.assertEquals(exc['value'], 'This is a test ValueError')
             self.assertTrue('sentry.interfaces.Message' in event)
@@ -94,7 +94,7 @@ class LogbookHandlerTest(TestCase):
             self.assertEquals(len(client.events), 1)
             event = client.events.pop(0)
             self.assertEquals(event['message'], 'This is a test of args')
-            self.assertFalse('sentry.interfaces.Exception' in event)
+            assert 'exception' not in event
             self.assertTrue('sentry.interfaces.Message' in event)
             msg = event['sentry.interfaces.Message']
             self.assertEquals(msg['message'], 'This is a test of {0}')
